## Changes

### 1.0.0 (2023-05-16)

- fix the cyclic dependency display to show all edges of a cycle in dark violet. [@jensens]
- fix graph of cycles not to show graph multiple times. [@jensens]

### 1.0.0a1 (2023-05-15)

- initial code [jensens]